from .config import Config, ctypes
from .config import auto_encode

# __int64 __stdcall HCFP_Capture(__int32 窗口序号, __int32 x, __int32 y, __int32 w, __int32 h, char* fileNamePath, BOOL 是否打开查看器 = FALSE);
def HD识图_截图(窗口序号: int, x: int, y: int, w: int, h: int, fileNamePath: str, 是否打开查看器: bool = False) -> int:
    """
    截图并保存到文件(.bmp)
    :param 窗口序号: 窗口序号 (从1开始)
    :param x: 矩形范围左上角x
    :param y: 矩形范围左上角y
    :param w: 矩形范围宽度
    :param h: 矩形范围高度
    :param fileNamePath: 保存到文件的路径+文件名(.bmp)
    :param 是否打开查看器: 是否打开查看
    :return:
    """
    hd = Config.get_hd()
    hd.HCFP_Capture.restype = ctypes.c_int64
    # 定义函数指针类型
    hd.HCFP_Capture.argtypes = [
        ctypes.c_int32,  # 窗口序号
        ctypes.c_int32,  # 矩形范围左上角x
        ctypes.c_int32,  # 矩形范围左上角y
        ctypes.c_int32,  # 矩形范围宽度
        ctypes.c_int32,  # 矩形范围高度
        ctypes.c_char_p,  # 保存到文件的路径+文件名(.bmp)
        ctypes.c_bool  # 是否打开查看
    ]
    ret = hd.HCFP_Capture(
        ctypes.c_int32(窗口序号),
        ctypes.c_int32(x),
        ctypes.c_int32(y),
        ctypes.c_int32(w),
        ctypes.c_int32(h),
        auto_encode(fileNamePath),
        ctypes.c_bool(是否打开查看器)
    )
    return ret
# __int64 __stdcall HCFP_FindColor(__int32 窗口序号, __int32 x, __int32 y, __int32 w, __int32 h, char* deltaColor, double sim, __int32 dirType);
def HD识图_单点找色(窗口序号: int, x: int, y: int, w: int, h: int, deltaColor: str, sim: float, dirType: int = 0) -> int:
    """
    单点找色
    :param 窗口序号: 窗口序号 (从1开始)
    :param x: 矩形范围左上角x
    :param y: 矩形范围左上角y
    :param w: 矩形范围宽度
    :param h: 矩形范围高度
    :param deltaColor: 偏色(如:303030) RGB 十六进制 RGB-偏色|000000-000000|000000-000000
    :param sim: 整个像素矩阵的相似度
    :param dirType: 排序类型 / 方向类型 (默认0)
    :return: 返回值代码 (查看HD返回值表)
    """
    hd = Config.get_hd()

    HCFP_FindColor = hd.HCFP_FindColor
    HCFP_FindColor.restype = ctypes.c_int64
    HCFP_FindColor.argtypes = [ctypes.c_int32, ctypes.c_int32, ctypes.c_int32, ctypes.c_int32, ctypes.c_int32, ctypes.c_char_p, ctypes.c_double, ctypes.c_int32]

    # 使用auto_encode自动转换编码
    deltaColor_bytes = auto_encode(deltaColor)

    ret = HCFP_FindColor(
        ctypes.c_int32(窗口序号),
        ctypes.c_int32(x),
        ctypes.c_int32(y),
        ctypes.c_int32(w),
        ctypes.c_int32(h),
        deltaColor_bytes,
        ctypes.c_double(sim),
        ctypes.c_int32(dirType)
    )
    return ret

# __int64 __stdcall HCFP_FindColors(__int32 窗口序号, __int32 x, __int32 y, __int32 w, __int32 h, char* deltaColor, double sim, __int32 dirType);
def HD识图_多点找色(窗口序号: int, x: int, y: int, w: int, h: int, deltaColor: str, sim: float, dirType: int = 0) -> int:
    """
    多点找色
    :param 窗口序号: 窗口序号 (从1开始)
    :param x: 矩形范围左上角x
    :param y: 矩形范围左上角y
    :param w: 矩形范围宽度
    :param h: 矩形范围高度
    :param deltaColor: 偏色(如:303030) RGB 十六进制 RGB-偏色|000000-000000|000000-000000
    :param sim: 整个像素矩阵的相似度
    :param dirType: 排序类型 / 方向类型 (默认0)
    :return: 返回值代码 (查看HD返回值表)
    """
    hd = Config.get_hd()

    HCFP_FindColors = hd.HCFP_FindColors
    HCFP_FindColors.restype = ctypes.c_int64
    HCFP_FindColors.argtypes = [ctypes.c_int32, ctypes.c_int32, ctypes.c_int32, ctypes.c_int32, ctypes.c_int32, ctypes.c_char_p, ctypes.c_double, ctypes.c_int32]

    # 使用auto_encode自动转换编码
    deltaColor_bytes = auto_encode(deltaColor)

    ret = HCFP_FindColors(
        ctypes.c_int32(窗口序号),
        ctypes.c_int32(x),
        ctypes.c_int32(y),
        ctypes.c_int32(w),
        ctypes.c_int32(h),
        deltaColor_bytes,
        ctypes.c_double(sim),
        ctypes.c_int32(dirType)
    )
    return ret

# __int64 __stdcall HCFP_FindColorsOffset(__int32 窗口序号, __int32 x, __int32 y, __int32 w, __int32 h, char* firstDeltaColor, char* deltaColor, double sim, __int32 bALL, __int32 dirType);
def HD识图_多点偏移找色(窗口序号: int, x: int, y: int, w: int, h: int, firstDeltaColor: str, deltaColor: str, sim: float, bALL: int = 0, dirType: int = 0) -> int:
    """
    多点偏移找色
    :param 窗口序号: 窗口序号 (从1开始)
    :param x: 矩形范围左上角x
    :param y: 矩形范围左上角y
    :param w: 矩形范围宽度
    :param h: 矩形范围高度
    :param firstDeltaColor: 首色 XXXXXX-YYYYYY 格式
    :param deltaColor: 偏移色 x1|y1|XXXXXX-YYYYYY| XXXXXX-YYYYYY| ...,x2|y3|XXXXXX-YYYYYY| XXXXXX-YYYYYY| ...,...格式
    :param sim: 整个像素矩阵的相似度
    :param bALL: 是否返回所有 (默认0)
    :param dirType: 排序类型 / 方向类型 (默认0)
    :return: 返回值代码 (查看HD返回值表)
    """
    hd = Config.get_hd()

    HCFP_FindColorsOffset = hd.HCFP_FindColorsOffset
    HCFP_FindColorsOffset.restype = ctypes.c_int64
    HCFP_FindColorsOffset.argtypes = [ctypes.c_int32, ctypes.c_int32, ctypes.c_int32, ctypes.c_int32, ctypes.c_int32, ctypes.c_char_p, ctypes.c_char_p, ctypes.c_double, ctypes.c_int32, ctypes.c_int32]

    # 使用auto_encode自动转换编码
    firstDeltaColor_bytes = auto_encode(firstDeltaColor)
    deltaColor_bytes = auto_encode(deltaColor)

    ret = HCFP_FindColorsOffset(
        ctypes.c_int32(窗口序号),
        ctypes.c_int32(x),
        ctypes.c_int32(y),
        ctypes.c_int32(w),
        ctypes.c_int32(h),
        firstDeltaColor_bytes,
        deltaColor_bytes,
        ctypes.c_double(sim),
        ctypes.c_int32(bALL),
        ctypes.c_int32(dirType)
    )
    return ret
# __int64 __stdcall HCFP_CmpColors(__int32 窗口序号, __int32 x, __int32 y, char* deltaColor);
def HD识图_比较颜色(窗口序号: int, x: int, y: int, deltaColor: str) -> int:
    """
    比较颜色
    :param 窗口序号: 窗口序号 (从1开始)
    :param x: 矩形范围左上角x
    :param y: 矩形范围左上角y
    :param deltaColor: XXXXXX-YYYYYY 格式
    :return: 返回值代码 (查看HD返回值表)
    """
    hd = Config.get_hd()

    HCFP_CmpColors = hd.HCFP_CmpColors
    HCFP_CmpColors.restype = ctypes.c_int64
    HCFP_CmpColors.argtypes = [ctypes.c_int32, ctypes.c_int32, ctypes.c_int32, ctypes.c_char_p]

    # 使用auto_encode自动转换编码
    deltaColor_bytes = auto_encode(deltaColor)

    ret = HCFP_CmpColors(
        ctypes.c_int32(窗口序号),
        ctypes.c_int32(x),
        ctypes.c_int32(y),
        deltaColor_bytes
    )
    return ret

# __int64 __stdcall HCFP_CmpColorExs(__int32 窗口序号, char* deltaXYColor);
def HD识图_比较颜色Ex(窗口序号: int, deltaXYColor: str) -> int:
    """
    多点找色确定某个图像块,指定多个具体点
    :param 窗口序号: 窗口序号 (从1开始)
    :param deltaXYColor: x1|y1|e3e6eb-101010|e3e6eb-101010|e3e6eb-101010|...,x2|y2|e3e6eb-101010|e3e6eb-101010|e3e6eb-101010|...
    :return: 返回值代码 (查看HD返回值表)
    """
    hd = Config.get_hd()

    HCFP_CmpColorExs = hd.HCFP_CmpColorExs
    HCFP_CmpColorExs.restype = ctypes.c_int64
    HCFP_CmpColorExs.argtypes = [ctypes.c_int32, ctypes.c_char_p]

    # 使用auto_encode自动转换编码
    deltaXYColor_bytes = auto_encode(deltaXYColor)

    ret = HCFP_CmpColorExs(
        ctypes.c_int32(窗口序号),
        deltaXYColor_bytes
    )
    return ret
# __int64 __stdcall HCFP_GetColor(__int32 窗口序号, __int32 x, __int32 y);
def HD识图_获取颜色(窗口序号: int, x: int, y: int) -> int:
    """
    获取某个点的颜色值
    :param 窗口序号: 窗口序号 (从1开始)
    :param x: 矩形范围左上角x
    :param y: 矩形范围左上角y
    :return: 返回值代码 (查看HD返回值表)
    """
    hd = Config.get_hd()

    HCFP_GetColor = hd.HCFP_GetColor
    HCFP_GetColor.restype = ctypes.c_int64
    HCFP_GetColor.argtypes = [ctypes.c_int32, ctypes.c_int32, ctypes.c_int32]

    ret = HCFP_GetColor(
        ctypes.c_int32(窗口序号),
        ctypes.c_int32(x),
        ctypes.c_int32(y)
    )
    return ret
# __int64 __stdcall HCFP_FindPic(__int32 窗口序号, __int32 x, __int32 y, __int32 w, __int32 h, char* 图片名字, char* deltaColor, double sim, __int32 dirType);
def HD识图_范围找图(窗口序号: int, x: int, y: int, w: int, h: int, 图片名字: str, deltaColor: str, sim: float, dirType: int = 0) -> int:
    """
    在客户区范围内找图
    :param 窗口序号: 窗口序号 (从1开始)
    :param x: 矩形范围左上角x
    :param y: 矩形范围左上角y
    :param w: 矩形范围宽度
    :param h: 矩形范围高度
    :param 图片名字: 一张图片(bmp)文件名字(不包含路径，路径调用HCRES_SetResPath全局设置)
    :param deltaColor: 偏色(如:303030) RGB 十六进制
    :param sim: 整个像素矩阵的相似度
    :param dirType: 排序类型 / 方向类型 (默认0)
    :return: 返回值代码 (查看HD返回值表)
    """
    hd = Config.get_hd()

    HCFP_FindPic = hd.HCFP_FindPic
    HCFP_FindPic.restype = ctypes.c_int64
    HCFP_FindPic.argtypes = [ctypes.c_int32, ctypes.c_int32, ctypes.c_int32, ctypes.c_int32, ctypes.c_int32, ctypes.c_char_p, ctypes.c_char_p, ctypes.c_double, ctypes.c_int32]

    # 使用auto_encode自动转换编码
    图片名字_bytes = auto_encode(图片名字)
    deltaColor_bytes = auto_encode(deltaColor)

    ret = HCFP_FindPic(
        ctypes.c_int32(窗口序号),
        ctypes.c_int32(x),
        ctypes.c_int32(y),
        ctypes.c_int32(w),
        ctypes.c_int32(h),
        图片名字_bytes,
        deltaColor_bytes,
        ctypes.c_double(sim),
        ctypes.c_int32(dirType)
    )
    return ret
# __int64 __stdcall HCFP_FindPicEx(__int32 窗口序号, __int32 x, __int32 y, __int32 w, __int32 h, char* 图片名字集合, char* deltaColor, double sim, __int32 dirType);
def HD识图_范围找图Ex(窗口序号: int, x: int, y: int, w: int, h: int, 图片名字集合: str, deltaColor: str, sim: float, dirType: int = 0) -> int:
    """
    在客户区范围内找图 (返回找到其中一张信息)
    :param 窗口序号: 窗口序号 (从1开始)
    :param x: 矩形范围左上角x
    :param y: 矩形范围左上角y
    :param w: 矩形范围宽度
    :param h: 矩形范围高度
    :param 图片名字集合: 多张张图片(bmp)文件名字(不包含路径，路径调用HCRES_SetResPath全局设置) ,以'|'分隔开
    :param deltaColor: 偏色(如:303030) RGB 十六进制
    :param sim: 整个像素矩阵的相似度
    :param dirType: 排序类型 / 方向类型 (默认0)
    :return: 返回值代码 (查看HD返回值表)
    """
    hd = Config.get_hd()

    HCFP_FindPicEx = hd.HCFP_FindPicEx
    HCFP_FindPicEx.restype = ctypes.c_int64
    HCFP_FindPicEx.argtypes = [ctypes.c_int32, ctypes.c_int32, ctypes.c_int32, ctypes.c_int32, ctypes.c_int32, ctypes.c_char_p, ctypes.c_char_p, ctypes.c_double, ctypes.c_int32]

    # 使用auto_encode自动转换编码
    图片名字集合_bytes = auto_encode(图片名字集合)
    deltaColor_bytes = auto_encode(deltaColor)

    ret = HCFP_FindPicEx(
        ctypes.c_int32(窗口序号),
        ctypes.c_int32(x),
        ctypes.c_int32(y),
        ctypes.c_int32(w),
        ctypes.c_int32(h),
        图片名字集合_bytes,
        deltaColor_bytes,
        ctypes.c_double(sim),
        ctypes.c_int32(dirType)
    )
    return ret


# __int64 __stdcall HCFP_IsDisplayDead(__int32 窗口序号, __int32 x, __int32 y, __int32 w, __int32 h, __int32 mstime);
def HD识图_是否卡屏(窗口序号: int, x: int, y: int, w: int, h: int, mstime: int) -> int:
    """
    在客户区范围内检测再规定时间内是否卡图
    :param 窗口序号: 窗口序号 (从1开始)
    :param x: 矩形范围左上角x
    :param y: 矩形范围左上角y
    :param w: 矩形范围宽度
    :param h: 矩形范围高度
    :param mstime: 间隔时间(不变就说明卡屏了),不会卡主线程
    :return: 返回值代码 (查看HD返回值表)
    """
    hd = Config.get_hd()

    HCFP_IsDisplayDead = hd.HCFP_IsDisplayDead
    HCFP_IsDisplayDead.restype = ctypes.c_int64
    HCFP_IsDisplayDead.argtypes = [ctypes.c_int32, ctypes.c_int32, ctypes.c_int32, ctypes.c_int32, ctypes.c_int32, ctypes.c_int32]

    ret = HCFP_IsDisplayDead(
        ctypes.c_int32(窗口序号),
        ctypes.c_int32(x),
        ctypes.c_int32(y),
        ctypes.c_int32(w),
        ctypes.c_int32(h),
        ctypes.c_int32(mstime)
    )
    return ret
# __int64 __stdcall HCFP_GetRangeCRC(__int32 窗口序号, __int32 x, __int32 y, __int32 w, __int32 h);
def HD识图_获取区域图像CRC(窗口序号: int, x: int, y: int, w: int, h: int) -> int:
    """
    在客户区范围内获取像素CRC值,用于卡屏校验
    :param 窗口序号: 窗口序号 (从1开始)
    :param x: 矩形范围左上角x
    :param y: 矩形范围左上角y
    :param w: 矩形范围宽度
    :param h: 矩形范围高度
    :return: 返回值代码 (查看HD返回值表)
    """
    hd = Config.get_hd()

    HCFP_GetRangeCRC = hd.HCFP_GetRangeCRC
    HCFP_GetRangeCRC.restype = ctypes.c_int64
    HCFP_GetRangeCRC.argtypes = [ctypes.c_int32, ctypes.c_int32, ctypes.c_int32, ctypes.c_int32, ctypes.c_int32]

    ret = HCFP_GetRangeCRC(
        ctypes.c_int32(窗口序号),
        ctypes.c_int32(x),
        ctypes.c_int32(y),
        ctypes.c_int32(w),
        ctypes.c_int32(h)
    )
    return ret
# __int64 __stdcall HCFP_FindColorByFile(__int32 窗口序号, char* orgImageName, __int32 x, __int32 y, __int32 w, __int32 h, char* deltaColor, double sim, __int32 dirType);
def HD识图_单点找色从文件(窗口序号: int, orgImageName: str, x: int, y: int, w: int, h: int, deltaColor: str, sim: float, dirType: int = 0) -> int:
    """
    单点找色(从文件)
    :param 窗口序号: 窗口序号 (从1开始)
    :param orgImageName: 指定一张原图数据(支持绝对路径和相对路径)bmp图片文件
    :param x: 矩形范围左上角x
    :param y: 矩形范围左上角y
    :param w: 矩形范围宽度
    :param h: 矩形范围高度
    :param deltaColor: 偏色(如:303030) RGB 十六进制
    :param sim: 整个像素矩阵的相似度
    :param dirType: 排序类型 / 方向类型 (默认0)
    :return: 返回值代码 (查看HD返回值表)
    """
    hd = Config.get_hd()

    HCFP_FindColorByFile = hd.HCFP_FindColorByFile
    HCFP_FindColorByFile.restype = ctypes.c_int64
    HCFP_FindColorByFile.argtypes = [ctypes.c_int32, ctypes.c_char_p, ctypes.c_int32, ctypes.c_int32, ctypes.c_int32, ctypes.c_int32, ctypes.c_char_p, ctypes.c_double, ctypes.c_int32]

    # 使用auto_encode自动转换编码
    orgImageName_bytes = auto_encode(orgImageName)
    deltaColor_bytes = auto_encode(deltaColor)

    ret = HCFP_FindColorByFile(
        ctypes.c_int32(窗口序号),
        orgImageName_bytes,
        ctypes.c_int32(x),
        ctypes.c_int32(y),
        ctypes.c_int32(w),
        ctypes.c_int32(h),
        deltaColor_bytes,
        ctypes.c_double(sim),
        ctypes.c_int32(dirType)
    )
    return ret

# __int64 __stdcall HCFP_FindColorByMem(__int32 窗口序号, BYTE* data, __int32 dataSize, __int32 x, __int32 y, __int32 w, __int32 h, char* deltaColor, double sim, __int32 dirType);
def HD识图_单点找色从内存(窗口序号: int, data: bytes, dataSize: int, x: int, y: int, w: int, h: int, deltaColor: str, sim: float, dirType: int = 0) -> int:
    """
    单点找色(从内存)
    :param 窗口序号: 窗口序号 (从1开始)
    :param data: Bmp图片字节数据缓冲区地址
    :param dataSize: Bmp图片字节大小
    :param x: 矩形范围左上角x
    :param y: 矩形范围左上角y
    :param w: 矩形范围宽度
    :param h: 矩形范围高度
    :param deltaColor: 偏色(如:303030) RGB 十六进制
    :param sim: 整个像素矩阵的相似度
    :param dirType: 排序类型 / 方向类型 (默认0)
    :return: 返回值代码 (查看HD返回值表)
    """
    hd = Config.get_hd()

    HCFP_FindColorByMem = hd.HCFP_FindColorByMem
    HCFP_FindColorByMem.restype = ctypes.c_int64
    HCFP_FindColorByMem.argtypes = [ctypes.c_int32, ctypes.c_void_p, ctypes.c_int32, ctypes.c_int32, ctypes.c_int32, ctypes.c_int32, ctypes.c_int32, ctypes.c_char_p, ctypes.c_double, ctypes.c_int32]

    # 使用auto_encode自动转换编码
    deltaColor_bytes = auto_encode(deltaColor)

    ret = HCFP_FindColorByMem(
        ctypes.c_int32(窗口序号),
        data,
        ctypes.c_int32(dataSize),
        ctypes.c_int32(x),
        ctypes.c_int32(y),
        ctypes.c_int32(w),
        ctypes.c_int32(h),
        deltaColor_bytes,
        ctypes.c_double(sim),
        ctypes.c_int32(dirType)
    )
    return ret

# __int64 __stdcall HCFP_FindColorsByFile(__int32 窗口序号, char* orgImageName, __int32 x, __int32 y, __int32 w, __int32 h, char* deltaColor, double sim, __int32 dirType);
def HD识图_多点找色从文件(窗口序号: int, orgImageName: str, x: int, y: int, w: int, h: int, deltaColor: str, sim: float, dirType: int = 0) -> int:
    """
    多点找色(从文件)
    :param 窗口序号: 窗口序号 (从1开始)
    :param orgImageName: 指定一张原图数据(支持绝对路径和相对路径)bmp图片文件
    :param x: 矩形范围左上角x
    :param y: 矩形范围左上角y
    :param w: 矩形范围宽度
    :param h: 矩形范围高度
    :param deltaColor: 偏色(如:303030) RGB 十六进制
    :param sim: 整个像素矩阵的相似度
    :param dirType: 排序类型 / 方向类型 (默认0)
    :return: 返回值代码 (查看HD返回值表)
    """
    hd = Config.get_hd()

    HCFP_FindColorsByFile = hd.HCFP_FindColorsByFile
    HCFP_FindColorsByFile.restype = ctypes.c_int64
    HCFP_FindColorsByFile.argtypes = [ctypes.c_int32, ctypes.c_char_p, ctypes.c_int32, ctypes.c_int32, ctypes.c_int32, ctypes.c_int32, ctypes.c_char_p, ctypes.c_double, ctypes.c_int32]

    # 使用auto_encode自动转换编码
    orgImageName_bytes = auto_encode(orgImageName)
    deltaColor_bytes = auto_encode(deltaColor)

    ret = HCFP_FindColorsByFile(
        ctypes.c_int32(窗口序号),
        orgImageName_bytes,
        ctypes.c_int32(x),
        ctypes.c_int32(y),
        ctypes.c_int32(w),
        ctypes.c_int32(h),
        deltaColor_bytes,
        ctypes.c_double(sim),
        ctypes.c_int32(dirType)
    )
    return ret

# __int64  __stdcall   HCFP_FindColorsByMem(__int32 窗口序号, BYTE* data, __int32 dataSize, __int32 x, __int32 y, __int32 w, __int32 h, char* deltaColor, double sim, __int32 dirType= 0);
def HD识图_多点找色从内存(窗口序号: int, data: bytes, dataSize: int, x: int, y: int, w: int, h: int, deltaColor: str, sim: float, dirType: int = 0) -> int:
    """
    多点找色(从内存)
    :param 窗口序号: 窗口序号 (从1开始)
    :param data: Bmp图片字节数据缓冲区地址
    :param dataSize: Bmp图片字节大小
    :param x: 矩形范围左上角x
    :param y: 矩形范围左上角y
    :param w: 矩形范围宽度
    :param h: 矩形范围高度
    :param deltaColor: 偏色(如:303030) RGB 十六进制
    :param sim: 整个像素矩阵的相似度
    :param dirType: 排序类型 / 方向类型 (默认0)
    :return: 返回值代码 (查看HD返回值表)
    """
    hd = Config.get_hd()

    HCFP_FindColorsByMem = hd.HCFP_FindColorsByMem
    HCFP_FindColorsByMem.restype = ctypes.c_int64
    HCFP_FindColorsByMem.argtypes = [ctypes.c_int32, ctypes.c_void_p, ctypes.c_int32, ctypes.c_int32, ctypes.c_int32, ctypes.c_int32, ctypes.c_int32, ctypes.c_char_p, ctypes.c_double, ctypes.c_int32]

    # 使用auto_encode自动转换编码
    deltaColor_bytes = auto_encode(deltaColor)

    ret = HCFP_FindColorsByMem(
        ctypes.c_int32(窗口序号),
        data,
        ctypes.c_int32(dataSize),
        ctypes.c_int32(x),
        ctypes.c_int32(y),
        ctypes.c_int32(w),
        ctypes.c_int32(h),
        deltaColor_bytes,
        ctypes.c_double(sim),
        ctypes.c_int32(dirType)
    )
    return ret

# __int64 __stdcall HCFP_FindColorsOffsetByFile(__int32 窗口序号, char* orgImageName, __int32 x, __int32 y, __int32 w, __int32 h, char* firstDeltaColor, char* deltaColor, double sim, __int32 bALL, __int32 dirType);
def HD识图_多点偏移找色从文件(窗口序号: int, orgImageName: str, x: int, y: int, w: int, h: int, firstDeltaColor: str, deltaColor: str, sim: float, bALL: int = 0, dirType: int = 0) -> int:
    """
    多点偏移找色(从文件)
    :param 窗口序号: 窗口序号 (从1开始)
    :param orgImageName: 指定一张原图数据(支持绝对路径和相对路径)bmp图片文件
    :param x: 矩形范围左上角x
    :param y: 矩形范围左上角y
    :param w: 矩形范围宽度
    :param h: 矩形范围高度
    :param firstDeltaColor: 偏色(如:303030) RGB 十六进制
    :param deltaColor: 偏色(如:303030) RGB 十六进制
    :param sim: 整个像素矩阵的相似度
    :param bALL: 是否全部 (默认0)
    :param dirType: 排序类型 / 方向类型 (默认0)
    :return: 返回值代码 (查看HD返回值表)
    """
    hd = Config.get_hd()

    HCFP_FindColorsOffsetByFile = hd.HCFP_FindColorsOffsetByFile
    HCFP_FindColorsOffsetByFile.restype = ctypes.c_int64
    HCFP_FindColorsOffsetByFile.argtypes = [ctypes.c_int32, ctypes.c_char_p, ctypes.c_int32, ctypes.c_int32, ctypes.c_int32, ctypes.c_int32, ctypes.c_char_p, ctypes.c_char_p, ctypes.c_double, ctypes.c_int32, ctypes.c_int32]

    # 使用auto_encode自动转换编码
    orgImageName_bytes = auto_encode(orgImageName)
    firstDeltaColor_bytes = auto_encode(firstDeltaColor)
    deltaColor_bytes = auto_encode(deltaColor)

    ret = HCFP_FindColorsOffsetByFile(
        ctypes.c_int32(窗口序号),
        orgImageName_bytes,
        ctypes.c_int32(x),
        ctypes.c_int32(y),
        ctypes.c_int32(w),
        ctypes.c_int32(h),
        firstDeltaColor_bytes,
        deltaColor_bytes,
        ctypes.c_double(sim),
        ctypes.c_int32(bALL),
        ctypes.c_int32(dirType)
    )
    return ret
# __int64 __stdcall HCFP_FindColorsOffsetByMem(__int32 窗口序号, BYTE* data, __int32 dataSize, __int32 x, __int32 y, __int32 w, __int32 h, char* firstDeltaColor, char* deltaColor, double sim, __int32 bALL, __int32 dirType);
def HD识图_多点偏移找色从内存(窗口序号: int, data: bytes, dataSize: int, x: int, y: int, w: int, h: int, firstDeltaColor: str, deltaColor: str, sim: float, bALL: int = 0, dirType: int = 0) -> int:
    """
    多点偏移找色(从内存)
    :param 窗口序号: 窗口序号 (从1开始)
    :param data: Bmp图片字节数据缓冲区地址
    :param dataSize: Bmp图片字节大小
    :param x: 矩形范围左上角x
    :param y: 矩形范围左上角y
    :param w: 矩形范围宽度
    :param h: 矩形范围高度
    :param firstDeltaColor: 偏色(如:303030) RGB 十六进制
    :param deltaColor: 偏色(如:303030) RGB 十六进制
    :param sim: 整个像素矩阵的相似度
    :param bALL: 是否全部 (默认0)
    :param dirType: 排序类型 / 方向类型 (默认0)
    :return: 返回值代码 (查看HD返回值表)
    """
    hd = Config.get_hd()

    HCFP_FindColorsOffsetByMem = hd.HCFP_FindColorsOffsetByMem
    HCFP_FindColorsOffsetByMem.restype = ctypes.c_int64
    HCFP_FindColorsOffsetByMem.argtypes = [ctypes.c_int32, ctypes.c_void_p, ctypes.c_int32, ctypes.c_int32, ctypes.c_int32, ctypes.c_int32, ctypes.c_int32, ctypes.c_char_p, ctypes.c_char_p, ctypes.c_double, ctypes.c_int32, ctypes.c_int32]

    # 使用auto_encode自动转换编码
    firstDeltaColor_bytes = auto_encode(firstDeltaColor)
    deltaColor_bytes = auto_encode(deltaColor)

    ret = HCFP_FindColorsOffsetByMem(
        ctypes.c_int32(窗口序号),
        data,
        ctypes.c_int32(dataSize),
        ctypes.c_int32(x),
        ctypes.c_int32(y),
        ctypes.c_int32(w),
        ctypes.c_int32(h),
        firstDeltaColor_bytes,
        deltaColor_bytes,
        ctypes.c_double(sim),
        ctypes.c_int32(bALL),
        ctypes.c_int32(dirType)
    )
    return ret

# __int64 __stdcall HCFP_FindPicByFile(__int32 窗口序号, char* orgImageName, __int32 x, __int32 y, __int32 w, __int32 h, char* 图片名字, char* deltaColor, double sim, __int32 dirType);
def HD识图_范围找图从文件(窗口序号: int, 原图名字: str, x: int, y: int, w: int, h: int, 图片名字: str, deltaColor: str, sim: float = 0.9, dirType: int = 0) -> int:
    """
    范围找图(从文件)
    :param 窗口序号: 窗口序号 (从1开始)
    :param 原图名字: 指定一张原图文件名(支持绝对路径和相对路径)
    :param x: 左上角x
    :param y: 左上角y
    :param w: 宽度
    :param h: 高度
    :param 图片名字: 如:hd1.bmp|hd2.bmp|hd3.bmp|hd4.bmp|
    :param deltaColor: 偏色(如:303030) RGB 十六进制
    :param sim: 相似度0-1 (默认0.9)
    :param dirType: 方向类型 (默认0)
    :return: 返回值代码 (查看HD返回值表)
    """
    hd = Config.get_hd()

    HCFP_FindPicByFile = hd.HCFP_FindPicByFile
    HCFP_FindPicByFile.restype = ctypes.c_int64
    HCFP_FindPicByFile.argtypes = [ctypes.c_int32, ctypes.c_char_p, ctypes.c_int32, ctypes.c_int32, ctypes.c_int32, ctypes.c_int32, ctypes.c_char_p, ctypes.c_char_p, ctypes.c_double, ctypes.c_int32]

    # 使用auto_encode自动转换编码
    原图名字_bytes = auto_encode(原图名字)
    图片名字_bytes = auto_encode(图片名字)
    deltaColor_bytes = auto_encode(deltaColor)

    ret = HCFP_FindPicByFile(
        ctypes.c_int32(窗口序号),
        原图名字_bytes,
        ctypes.c_int32(x),
        ctypes.c_int32(y),
        ctypes.c_int32(w),
        ctypes.c_int32(h),
        图片名字_bytes,
        deltaColor_bytes,
        ctypes.c_double(sim),
        ctypes.c_int32(dirType)
    )
    return ret
# __int64 __stdcall HCFP_FindPicByMem(__int32 窗口序号, BYTE* data, __int32 dataSize, __int32 x, __int32 y, __int32 w, __int32 h, char* 图片名字, char* deltaColor, double sim, __int32 dirType);
def HD识图_范围找图从内存(窗口序号: int, data: bytes, dataSize: int, x: int, y: int, w: int, h: int, 图片名字: str, deltaColor: str, sim: float = 0.9, dirType: int = 0) -> int:
    """
    范围找图(从内存)
    :param 窗口序号: 窗口序号 (从1开始)
    :param data: 图片数据
    :param dataSize: 图片数据长度
    :param x: 左上角x
    :param y: 左上角y
    :param w: 宽度
    :param h: 高度
    :param 图片名字: 一张图片(bmp)文件名字(路径调用HCRES_SetResPath全局设置) (支持绝对路径和相对路径)
    :param deltaColor: 偏色(如:303030) RGB 十六进制
    :param sim: 相似度0-1 (默认0.9)
    :param dirType: 方向类型 (默认0)
    :return: 返回值代码 (查看HD返回值表)
    """
    hd = Config.get_hd()

    HCFP_FindPicByMem = hd.HCFP_FindPicByMem
    HCFP_FindPicByMem.restype = ctypes.c_int64
    HCFP_FindPicByMem.argtypes = [ctypes.c_int32, ctypes.c_void_p, ctypes.c_int32, ctypes.c_int32, ctypes.c_int32, ctypes.c_int32, ctypes.c_int32, ctypes.c_char_p, ctypes.c_char_p, ctypes.c_double, ctypes.c_int32]

    # 使用auto_encode自动转换编码
    图片名字_bytes = auto_encode(图片名字)
    deltaColor_bytes = auto_encode(deltaColor)

    ret = HCFP_FindPicByMem(
        ctypes.c_int32(窗口序号),
        data,
        ctypes.c_int32(dataSize),
        ctypes.c_int32(x),
        ctypes.c_int32(y),
        ctypes.c_int32(w),
        ctypes.c_int32(h),
        图片名字_bytes,
        deltaColor_bytes,
        ctypes.c_double(sim),
        ctypes.c_int32(dirType)
    )
    return ret
# __int64 __stdcall HCFP_FindPicExByFile(__int32 窗口序号, char* orgImageName, __int32 x, __int32 y, __int32 w, __int32 h, char* 图片名字集合, char* deltaColor, double sim, __int32 dirType);
def HD识图_范围找图从文件Ex(窗口序号: int, 原图名字: str, x: int, y: int, w: int, h: int, 图片名字: str, deltaColor: str, sim: float = 0.9, dirType: int = 0) -> int:
    """
    范围找图(从文件)Ex
    :param 窗口序号: 窗口序号 (从1开始)
    :param 原图名字: 指定一张原图文件名(支持绝对路径和相对路径)
    :param x: 左上角x
    :param y: 左上角y
    :param w: 宽度
    :param h: 高度
    :param 图片名字: 如:hd1.bmp|hd2.bmp|hd3.bmp|hd4.bmp|
    :param deltaColor: 偏色(如:303030) RGB 十六进制
    :param sim: 相似度0-1 (默认0.9)
    :param dirType: 方向类型 (默认0)
    :return: 返回值代码 (查看HD返回值表)
    """
    hd = Config.get_hd()

    HCFP_FindPicExByFile = hd.HCFP_FindPicExByFile
    HCFP_FindPicExByFile.restype = ctypes.c_int64
    HCFP_FindPicExByFile.argtypes = [ctypes.c_int32, ctypes.c_char_p, ctypes.c_int32, ctypes.c_int32, ctypes.c_int32, ctypes.c_int32, ctypes.c_char_p, ctypes.c_char_p, ctypes.c_double, ctypes.c_int32]

    # 使用auto_encode自动转换编码
    原图名字_bytes = auto_encode(原图名字)
    图片名字_bytes = auto_encode(图片名字)
    deltaColor_bytes = auto_encode(deltaColor)

    ret = HCFP_FindPicExByFile(
        ctypes.c_int32(窗口序号),
        原图名字_bytes,
        ctypes.c_int32(x),
        ctypes.c_int32(y),
        ctypes.c_int32(w),
        ctypes.c_int32(h),
        图片名字_bytes,
        deltaColor_bytes,
        ctypes.c_double(sim),
        ctypes.c_int32(dirType)
    )
    return ret

# __int64 __stdcall HCFP_FindPicExByMem(__int32 窗口序号, BYTE* data, __int32 dataSize, __int32 x, __int32 y, __int32 w, __int32 h, char* 图片名字集合, char* deltaColor, double sim, __int32 dirType);
def HD识图_范围找图从内存Ex(窗口序号: int, data: bytes, dataSize: int, x: int, y: int, w: int, h: int, 图片名字: str, deltaColor: str, sim: float = 0.9, dirType: int = 0) -> int:
    """
    范围找图(从内存)Ex
    :param 窗口序号: 窗口序号 (从1开始)
    :param data: 图片数据
    :param dataSize: 图片数据长度
    :param x: 左上角x
    :param y: 左上角y
    :param w: 宽度
    :param h: 高度
    :param 图片名字: 如:hd1.bmp|hd2.bmp|hd3.bmp|hd4.bmp|
    :param deltaColor: 偏色(如:303030) RGB 十六进制
    :param sim: 相似度0-1 (默认0.9)
    :param dirType: 方向类型 (默认0)
    :return: 返回值代码 (查看HD返回值表)
    """
    hd = Config.get_hd()

    HCFP_FindPicExByMem = hd.HCFP_FindPicExByMem
    HCFP_FindPicExByMem.restype = ctypes.c_int64
    HCFP_FindPicExByMem.argtypes = [ctypes.c_int32, ctypes.c_void_p, ctypes.c_int32, ctypes.c_int32, ctypes.c_int32, ctypes.c_int32, ctypes.c_int32, ctypes.c_char_p, ctypes.c_char_p, ctypes.c_double, ctypes.c_int32]

    # 使用auto_encode自动转换编码
    图片名字_bytes = auto_encode(图片名字)
    deltaColor_bytes = auto_encode(deltaColor)

    ret = HCFP_FindPicExByMem(
        ctypes.c_int32(窗口序号),
        data,
        ctypes.c_int32(dataSize),
        ctypes.c_int32(x),
        ctypes.c_int32(y),
        ctypes.c_int32(w),
        ctypes.c_int32(h),
        图片名字_bytes,
        deltaColor_bytes,
        ctypes.c_double(sim),
        ctypes.c_int32(dirType)
    )
    return ret
# __int64 __stdcall HCFP_FindPicExFromMem(__int32 窗口序号, __int32 x, __int32 y, __int32 w, __int32 h, char* 子图内存地址集合字符串, char* deltaColor, double sim, __int32 dirType);
def HD识图_范围找图来源内存Ex(窗口序号: int, x: int, y: int, w: int, h: int, 子图内存地址集合字符串: str, deltaColor: str, sim: float = 0.9, dirType: int = 0) -> int:
    """
    范围找图(来源内存)Ex
    :param 窗口序号: 窗口序号 (从1开始)
    :param x: 左上角x
    :param y: 左上角y
    :param w: 宽度
    :param h: 高度
    :param 子图内存地址集合字符串: "地址1,长度1|地址2,长度2|地址3,长度3"  地址和长度用十进制表示
    :param deltaColor: 偏色(如:303030) RGB 十六进制
    :param sim: 相似度0-1 (默认0.9)
    :param dirType: 方向类型 (默认0)
    :return: 返回值代码 (查看HD返回值表)
    """
    hd = Config.get_hd()

    HCFP_FindPicExFromMem = hd.HCFP_FindPicExFromMem
    HCFP_FindPicExFromMem.restype = ctypes.c_int64
    HCFP_FindPicExFromMem.argtypes = [ctypes.c_int32, ctypes.c_int32, ctypes.c_int32, ctypes.c_int32, ctypes.c_int32, ctypes.c_char_p, ctypes.c_char_p, ctypes.c_double, ctypes.c_int32]

    # 使用auto_encode自动转换编码
    子图内存地址集合字符串_bytes = auto_encode(子图内存地址集合字符串)
    deltaColor_bytes = auto_encode(deltaColor)

    ret = HCFP_FindPicExFromMem(
        ctypes.c_int32(窗口序号),
        ctypes.c_int32(x),
        ctypes.c_int32(y),
        ctypes.c_int32(w),
        ctypes.c_int32(h),
        子图内存地址集合字符串_bytes,
        deltaColor_bytes,
        ctypes.c_double(sim),
        ctypes.c_int32(dirType)
    )
    return ret
# __int64 __stdcall HCFP_CmpColorsByFile(__int32 窗口序号, char* orgImageName, __int32 x, __int32 y, char* deltaColor);
def HD识图_比较颜色从文件(窗口序号: int, orgImageName: str, x: int, y: int, deltaColor: str) -> int:
    """
    比较颜色(从文件)
    :param 窗口序号: 窗口序号 (从1开始)
    :param orgImageName: 原图名字
    :param x: 坐标x
    :param y: 坐标y
    :param deltaColor: 偏色(如:303030) RGB 十六进制
    :return: 返回值代码 (查看HD返回值表)
    """
    hd = Config.get_hd()

    HCFP_CmpColorsByFile = hd.HCFP_CmpColorsByFile
    HCFP_CmpColorsByFile.restype = ctypes.c_int64
    HCFP_CmpColorsByFile.argtypes = [ctypes.c_int32, ctypes.c_char_p, ctypes.c_int32, ctypes.c_int32, ctypes.c_char_p]

    # 使用auto_encode自动转换编码
    orgImageName_bytes = auto_encode(orgImageName)
    deltaColor_bytes = auto_encode(deltaColor)

    ret = HCFP_CmpColorsByFile(
        ctypes.c_int32(窗口序号),
        orgImageName_bytes,
        ctypes.c_int32(x),
        ctypes.c_int32(y),
        deltaColor_bytes
    )
    return ret
# __int64 __stdcall HCFP_CmpColorsByMem(__int32 窗口序号, BYTE* data, __int32 dataSize, __int32 x, __int32 y, char* deltaColor);
def HD识图_比较颜色从内存(窗口序号: int, data: bytes, dataSize: int, x: int, y: int, deltaColor: str) -> int:
    """
    比较颜色(来源内存)
    :param 窗口序号: 窗口序号 (从1开始)
    :param data: Bmp图片字节数据缓冲区地址
    :param dataSize: Bmp图片字节大小
    :param x: 坐标x
    :param y: 坐标y
    :param deltaColor: 偏色(如:303030) RGB 十六进制
    :return: 返回值代码 (查看HD返回值表)
    """
    hd = Config.get_hd()

    HCFP_CmpColorsByMem = hd.HCFP_CmpColorsByMem
    HCFP_CmpColorsByMem.restype = ctypes.c_int64
    HCFP_CmpColorsByMem.argtypes = [ctypes.c_int32, ctypes.c_void_p, ctypes.c_int32, ctypes.c_int32, ctypes.c_int32, ctypes.c_char_p]

    # 使用auto_encode自动转换编码
    deltaColor_bytes = auto_encode(deltaColor)

    ret = HCFP_CmpColorsByMem(
        ctypes.c_int32(窗口序号),
        data,
        ctypes.c_int32(dataSize),
        ctypes.c_int32(x),
        ctypes.c_int32(y),
        deltaColor_bytes
    )
    return ret
# __int64 __stdcall HCFP_CmpColorExsByFile(__int32 窗口序号, char* orgImageName, char* deltaXYColor);
def HD识图_比较颜色从文件Ex(窗口序号: int, orgImageName: str, deltaXYColor: str) -> int:
    """
    多点找色确定某个图像块,指定多个具体点,从文件
    :param 窗口序号: 窗口序号 (从1开始)
    :param orgImageName: 原图名字
    :param deltaXYColor: 偏色坐标字符串 (如:"x1,y1,303030-x2,y2,404040")
    :return: 返回值代码 (查看HD返回值表)
    """
    hd = Config.get_hd()

    HCFP_CmpColorExsByFile = hd.HCFP_CmpColorExsByFile
    HCFP_CmpColorExsByFile.restype = ctypes.c_int64
    HCFP_CmpColorExsByFile.argtypes = [ctypes.c_int32, ctypes.c_char_p, ctypes.c_char_p]

    # 使用auto_encode自动转换编码
    orgImageName_bytes = auto_encode(orgImageName)
    deltaXYColor_bytes = auto_encode(deltaXYColor)

    ret = HCFP_CmpColorExsByFile(
        ctypes.c_int32(窗口序号),
        orgImageName_bytes,
        deltaXYColor_bytes
    )
    return ret
# __int64 __stdcall  HCFP_CmpColorExsByMem(__int32 窗口序号, BYTE* data, __int32 dataSize, char* deltaXYColor);
def HD识图_比较颜色从内存Ex(窗口序号: int, data: bytes, dataSize: int, deltaXYColor: str) -> int:
    """
    多点找色确定某个图像块,指定多个具体点,来源内存
    :param 窗口序号: 窗口序号 (从1开始)
    :param data: Bmp图片字节数据缓冲区地址
    :param dataSize: Bmp图片字节大小
    :param deltaXYColor: 偏色坐标字符串 (如:"x1,y1,303030-x2,y2,404040")
    :return: 返回值代码 (查看HD返回值表)
    """
    hd = Config.get_hd()

    HCFP_CmpColorExsByMem = hd.HCFP_CmpColorExsByMem
    HCFP_CmpColorExsByMem.restype = ctypes.c_int64
    HCFP_CmpColorExsByMem.argtypes = [ctypes.c_int32, ctypes.c_void_p, ctypes.c_int32, ctypes.c_char_p]

    # 使用auto_encode自动转换编码
    deltaXYColor_bytes = auto_encode(deltaXYColor)

    ret = HCFP_CmpColorExsByMem(
        ctypes.c_int32(窗口序号),
        data,
        ctypes.c_int32(dataSize),
        deltaXYColor_bytes
    )
    return ret
# __int64 __stdcall HCFP_GetColorByFile(__int32 窗口序号, char* orgImageName, __int32 x, __int32 y);
def HD识图_获取颜色从文件(窗口序号: int, orgImageName: str, x: int, y: int) -> int:
    """
    获取颜色(从文件)
    :param 窗口序号: 窗口序号 (从1开始)
    :param orgImageName: 原图名字
    :param x: 坐标x
    :param y: 坐标y
    :return: 返回值代码 (查看HD返回值表)
    """
    hd = Config.get_hd()

    HCFP_GetColorByFile = hd.HCFP_GetColorByFile
    HCFP_GetColorByFile.restype = ctypes.c_int64
    HCFP_GetColorByFile.argtypes = [ctypes.c_int32, ctypes.c_char_p, ctypes.c_int32, ctypes.c_int32]

    # 使用auto_encode自动转换编码
    orgImageName_bytes = auto_encode(orgImageName)

    ret = HCFP_GetColorByFile(
        ctypes.c_int32(窗口序号),
        orgImageName_bytes,
        ctypes.c_int32(x),
        ctypes.c_int32(y)
    )
    return ret

# __int64 __stdcall HCFP_GetColorByMem(__int32 窗口序号, BYTE* data, __int32 dataSize, __int32 x, __int32 y);
def HD识图_获取颜色从内存(窗口序号: int, data: bytes, dataSize: int, x: int, y: int) -> int:
    """
    获取颜色(来源内存)
    :param 窗口序号: 窗口序号 (从1开始)
    :param data: Bmp图片字节数据缓冲区地址
    :param dataSize: Bmp图片字节大小
    :param x: 坐标x
    :param y: 坐标y
    :return: 返回值代码 (查看HD返回值表)
    """
    hd = Config.get_hd()

    HCFP_GetColorByMem = hd.HCFP_GetColorByMem
    HCFP_GetColorByMem.restype = ctypes.c_int64
    HCFP_GetColorByMem.argtypes = [ctypes.c_int32, ctypes.c_void_p, ctypes.c_int32, ctypes.c_int32, ctypes.c_int32]

    ret = HCFP_GetColorByMem(
        ctypes.c_int32(窗口序号),
        data,
        ctypes.c_int32(dataSize),
        ctypes.c_int32(x),
        ctypes.c_int32(y)
    )
    return ret

def HD识图_范围找图EXX(
    window_index: int,
    x: int,
    y: int,
    w: int,
    h: int,
    pic_names: str,
    deltaColor: str,
    sim: float,
    bAll: bool = True,
    dirType: int = 0
) -> int:
    """
    接口说明:
        在客户区范围内找图 (返回全部找到的信息)

    函数原型 ：
        __int64 __stdcall  HCFP_FindPicExx(__int32 窗口序号, __int32 x, __int32 y, __int32 w, __int32 h, char*图片名字集合, char* deltaColor, double sim, BOOL bAll = TRUE, __int32 dirType = 0);

    参数说明:
        window_index: 窗口序号 (从1开始)  0表示全局全屏识别
        x: 矩形范围左上角x
        y: 矩形范围左上角y
        w: 矩形范围宽度
        h: 矩形范围高度
        pic_names: 多张图片(bmp)文件名字(不包含路径，路径调用HCRES_SetResPath全局设置) ,以'|'分隔开
        deltaColor: 偏色(如:303030) RGB 十六进制
        sim: 整个像素矩阵的相似度
        bAll: 是否全部找 如果不是表示每个图片只找一次就换下个图片
        dirType: 排序类型/方向类型

    返回值:
        int: 见HD返回值表，返回 0 1 或错误值
        返回json： {error:0,ret:[{bRet:NN,info:MM}]}
        MM：index1,x1,y1,w1,h1|index2,x2,y2,w3,h3|index3,x3,y3,w3,h3| 含义:  图片索引(0开始),左上角X,左上角Y,宽度,高度|

    备注:
        注意返回值含义和xy值的提取
    """
    hd = Config.get_hd()
    HCFP_FindPicExx = hd.HCFP_FindPicExx
    HCFP_FindPicExx.restype = ctypes.c_int64
    HCFP_FindPicExx.argtypes = [
        ctypes.c_int32, ctypes.c_int32, ctypes.c_int32, ctypes.c_int32, ctypes.c_int32,
        ctypes.c_char_p, ctypes.c_char_p, ctypes.c_double, ctypes.c_bool, ctypes.c_int32
    ]
    pic_names_bytes = auto_encode(pic_names)
    deltaColor_bytes = auto_encode(deltaColor)
    ret = HCFP_FindPicExx(
        ctypes.c_int32(window_index),
        ctypes.c_int32(x),
        ctypes.c_int32(y),
        ctypes.c_int32(w),
        ctypes.c_int32(h),
        pic_names_bytes,
        deltaColor_bytes,
        ctypes.c_double(sim),
        ctypes.c_bool(bAll),
        ctypes.c_int32(dirType)
    )
    return ret

def HD识图_范围找图从文件Exx(
    window_index: int,
    orgImageName: str,
    x: int,
    y: int,
    w: int,
    h: int,
    pic_names: str,
    deltaColor: str,
    sim: float,
    bAll: bool = True,
    dirType: int = 0
) -> int:
    """
    接口说明:
        在客户区范围内找图(从文件) (找全部图片信息坐标)

    函数原型 ：
        __int64  __stdcall  HCFP_FindPicExxByFile(__int32 窗口序号, char*orgImageName, __int32 x, __int32 y, __int32 w, __int32 h, char*图片名字集合, char* deltaColor, double sim, BOOL bAll = TRUE, __int32 dirType= 0);

    参数说明:
        window_index: 窗口序号 (从1开始) 0表示全局全屏识别
        orgImageName: 指定一张原图数据(支持绝对路径和相对路径)
        x: 矩形范围左上角x
        y: 矩形范围左上角y
        w: 矩形范围宽度
        h: 矩形范围高度
        pic_names: 多张图片(bmp)文件名字(不包含路径，路径调用HCRES_SetResPath全局设置) ,以'|'分隔开(支持绝对路径和相对路径)
        deltaColor: 偏色(如:303030) RGB 十六进制
        sim: 整个像素矩阵的相似度
        bAll: 是否全部找 如果不是表示每个图片只找一次就换下个图片
        dirType: 排序类型/方向类型

    返回值:
        int: 见HD返回值表，返回 0 1 或错误值
        返回json： {error:0,ret:[{bRet:NN,info:MM}]}
        MM： index1,x1,y1,w1,h1|index2,x2,y2,w3,h3|index3,x3,y3,w3,h3| 含义:   图片索引(0开始),左上角X,左上角Y,宽度,高度|

    备注:
        注意返回值含义和xy值的提取
    """
    hd = Config.get_hd()
    HCFP_FindPicExxByFile = hd.HCFP_FindPicExxByFile
    HCFP_FindPicExxByFile.restype = ctypes.c_int64
    HCFP_FindPicExxByFile.argtypes = [
        ctypes.c_int32, ctypes.c_char_p, ctypes.c_int32, ctypes.c_int32, ctypes.c_int32, ctypes.c_int32,
        ctypes.c_char_p, ctypes.c_char_p, ctypes.c_double, ctypes.c_bool, ctypes.c_int32
    ]
    orgImageName_bytes = auto_encode(orgImageName)
    pic_names_bytes = auto_encode(pic_names)
    deltaColor_bytes = auto_encode(deltaColor)
    ret = HCFP_FindPicExxByFile(
        ctypes.c_int32(window_index),
        orgImageName_bytes,
        ctypes.c_int32(x),
        ctypes.c_int32(y),
        ctypes.c_int32(w),
        ctypes.c_int32(h),
        pic_names_bytes,
        deltaColor_bytes,
        ctypes.c_double(sim),
        ctypes.c_bool(bAll),
        ctypes.c_int32(dirType)
    )
    return ret

def HD识图_范围找图来源内存Exx(
    window_index: int,
    x: int,
    y: int,
    w: int,
    h: int,
    sub_img_mem_str: str,
    deltaColor: str,
    sim: float,
    bAll: bool = True,
    dirType: int = 0
) -> int:
    """
    接口说明:
        在客户区范围内找图(子图从内存) (找全部图片信息坐标)

    函数原型 ：
        __int64  __stdcall  HCFP_FindPicExxFromMem(__int32 窗口序号, __int32 x, __int32 y, __int32 w, __int32 h, char*子图内存地址集合字符串, char* deltaColor, double sim,  BOOL bAll = TRUE, __int32 dirType= 0);

    参数说明:
        window_index: 窗口序号 (从1开始)  0表示全局全屏识别
        sub_img_mem_str: "地址1,长度1|地址2,长度2|地址3,长度3" 地址和长度用十进制表示
        x: 矩形范围左上角x
        y: 矩形范围左上角y
        w: 矩形范围宽度
        h: 矩形范围高度
        deltaColor: 偏色(如:303030) RGB 十六进制
        sim: 整个像素矩阵的相似度
        bAll: 是否全部找 如果不是表示每个图片只找一次就换下个图片
        dirType: 排序类型/方向类型

    返回值:
        int: 见HD返回值表，返回 0 1 或错误值
        返回json： {error:0,ret:[{bRet:NN,info:MM}]}
        MM：index1,x1,y1,w1,h1|index2,x2,y2,w3,h3|index3,x3,y3,w3,h3| 含义:   图片索引(0开始),左上角X,左上角Y,宽度,高度|

    备注:
        注意返回值含义和xy值的提取
        图片内存缓冲区自己维护
    """
    hd = Config.get_hd()
    HCFP_FindPicExxFromMem = hd.HCFP_FindPicExxFromMem
    HCFP_FindPicExxFromMem.restype = ctypes.c_int64
    HCFP_FindPicExxFromMem.argtypes = [
        ctypes.c_int32, ctypes.c_int32, ctypes.c_int32, ctypes.c_int32, ctypes.c_int32,
        ctypes.c_char_p, ctypes.c_char_p, ctypes.c_double, ctypes.c_bool, ctypes.c_int32
    ]
    sub_img_mem_str_bytes = auto_encode(sub_img_mem_str)
    deltaColor_bytes = auto_encode(deltaColor)
    ret = HCFP_FindPicExxFromMem(
        ctypes.c_int32(window_index),
        ctypes.c_int32(x),
        ctypes.c_int32(y),
        ctypes.c_int32(w),
        ctypes.c_int32(h),
        sub_img_mem_str_bytes,
        deltaColor_bytes,
        ctypes.c_double(sim),
        ctypes.c_bool(bAll),
        ctypes.c_int32(dirType)
    )
    return ret

def HD识图_范围找图从内存Exx(
    window_index: int,
    data: bytes,
    dataSize: int,
    x: int,
    y: int,
    w: int,
    h: int,
    pic_names: str,
    deltaColor: str,
    sim: float,
    bAll: bool = True,
    dirType: int = 0
) -> int:
    """
    接口说明:
        在客户区范围内找图(从内存)(找全部图片信息坐标)

    函数原型 ：
        __int64  __stdcall  HCFP_FindPicExxByMem(__int32 窗口序号, BYTE* data, __int32 dataSize, __int32 x, __int32 y, __int32 w, __int32 h, char*图片名字集合, char* deltaColor, double sim, BOOL bAll = TRUE, __int32 dirType= 0);

    参数说明:
        window_index: 窗口序号 (从1开始)  0表示全局全屏识别
        data: Bmp图片字节数据缓冲区地址
        dataSize: Bmp图片字节大小
        x: 矩形范围左上角x
        y: 矩形范围左上角y
        w: 矩形范围宽度
        h: 矩形范围高度
        pic_names: 多张图片(bmp)文件名字(不包含路径，路径调用HCRES_SetResPath全局设置) ,以'|'分隔开(支持绝对路径和相对路径)
        deltaColor: 偏色(如:303030) RGB 十六进制
        sim: 整个像素矩阵的相似度
        bAll: 是否全部找 如果不是表示每个图片只找一次就换下个图片
        dirType: 排序类型/方向类型

    返回值:
        int: 见HD返回值表，返回 0 1 或错误值
        返回json： {error:0,ret:[{bRet:NN,info:MM}]}
        MM： index1,x1,y1,w1,h1|index2,x2,y2,w3,h3|index3,x3,y3,w3,h3| 含义:  图片索引(0开始),左上角X,左上角Y,宽度,高度|

    备注:
        注意返回值含义和xy值的提取
        图片内存缓冲区自己维护
    """
    hd = Config.get_hd()
    HCFP_FindPicExxByMem = hd.HCFP_FindPicExxByMem
    HCFP_FindPicExxByMem.restype = ctypes.c_int64
    HCFP_FindPicExxByMem.argtypes = [
        ctypes.c_int32, ctypes.c_void_p, ctypes.c_int32, ctypes.c_int32, ctypes.c_int32, ctypes.c_int32, ctypes.c_int32,
        ctypes.c_char_p, ctypes.c_char_p, ctypes.c_double, ctypes.c_bool, ctypes.c_int32
    ]
    data_buffer = ctypes.create_string_buffer(data, dataSize)
    pic_names_bytes = auto_encode(pic_names)
    deltaColor_bytes = auto_encode(deltaColor)
    ret = HCFP_FindPicExxByMem(
        ctypes.c_int32(window_index),
        ctypes.cast(data_buffer, ctypes.c_void_p),
        ctypes.c_int32(dataSize),
        ctypes.c_int32(x),
        ctypes.c_int32(y),
        ctypes.c_int32(w),
        ctypes.c_int32(h),
        pic_names_bytes,
        deltaColor_bytes,
        ctypes.c_double(sim),
        ctypes.c_bool(bAll),
        ctypes.c_int32(dirType)
    )
    return ret


#!/usr/bin/env python
# -*- coding: utf-8 -*-
"""
HD-Python模块安装脚本

此脚本用于将HD-Python模块(HD目录)打包发布到PyPI或本地安装。
"""

from setuptools import setup, find_packages

# 主setup配置
setup(
    # 包元数据
    name="hdgdk",
    version="2.2.0 ",
    description="HD引擎Python调用模块",
    long_description="HD引擎Python调用模块",
    long_description_content_type="text/markdown",
    author="zhangsan",
    author_email="3258856837@qq.com",
    maintainer="zhangsan",
    maintainer_email="3258856837@qq.com",
    url="https://github.com/zhangsan-ai/hd-python",
    license="MIT",
    
    # 包配置
    packages=['HD'],
    include_package_data=False,
    zip_safe=False,
    
    # Python版本要求
    python_requires=">=3.6",
)


from .config import Config, ctypes
from .config import auto_encode

# INT64 __stdcall HCModule_AddComponent(int winIndex, char* account, char* password, char* componentPath, INT64 rcx, INT64 rdx, INT64 r8, INT64 r9, INT64 l5, INT64 l6, INT64 addType, BOOL autoInit, BOOL mainThread);
def HD插件_加载插件(窗口序号: int, 账号: str, 密码: str, 组件路径: str, rcx: int = 0, rdx: int = 0, r8: int = 0, r9: int = 0, l5: int = 0, l6: int = 0, 添加方式: int = -1, 是否自动初始化: bool = True, 是否主线程: bool = False) -> int:
    """
    添加自定义组件
    
    Args:
        窗口序号: 窗口序号
        账号: 开发者账号
        密码: 开发者密码
        组件路径: 组件绝对路径（请勿使用中文）
        rcx: CALL参数1
        rdx: CALL参数2
        r8: CALL参数3
        r9: CALL参数4
        l5: CALL参数5
        l6: CALL参数6
        添加方式: -1默认/1无痕不可卸载/2普通可卸载
        是否自动初始化: 自动调用初始化接口
        是否主线程: 需挂接主线程
    
    Returns:
        int: 返回值代码（查看HD返回值表）
    """
    hd = Config.get_hd()
    
    HCModule_AddComponent = hd.HCModule_AddComponent
    HCModule_AddComponent.restype = ctypes.c_int64
    HCModule_AddComponent.argtypes = [ctypes.c_int32, ctypes.c_char_p, ctypes.c_char_p, ctypes.c_char_p, ctypes.c_int64, ctypes.c_int64, ctypes.c_int64, ctypes.c_int64, ctypes.c_int64, ctypes.c_int64, ctypes.c_int64, ctypes.c_bool, ctypes.c_bool]
    
    ret = HCModule_AddComponent(
        ctypes.c_int32(窗口序号),
        auto_encode(账号),
        auto_encode(密码),
        auto_encode(组件路径),
        ctypes.c_int64(rcx),
        ctypes.c_int64(rdx),
        ctypes.c_int64(r8),
        ctypes.c_int64(r9),
        ctypes.c_int64(l5),
        ctypes.c_int64(l6),
        ctypes.c_int64(添加方式),
        ctypes.c_bool(是否自动初始化),
        ctypes.c_bool(是否主线程)
    )
    return ret

# INT64 __stdcall HCModule_DeleteComponent(int winIndex, char* componentName, BOOL mainThread);
def HD插件_卸载插件(窗口序号: int, 组件名: str, 是否主线程: bool = False) -> int:
    """
    无痕卸载DLL组件
    
    Args:
        窗口序号: 窗口序号
        组件名: 组件文件名（不含.dll）
        是否主线程: 需挂接主线程
    
    Returns:
        int: 返回值代码（查看HD返回值表）
    """
    hd = Config.get_hd()
    
    HCModule_DeleteComponent = hd.HCModule_DeleteComponent
    HCModule_DeleteComponent.restype = ctypes.c_int64
    HCModule_DeleteComponent.argtypes = [ctypes.c_int32, ctypes.c_char_p, ctypes.c_bool]
    
    ret = HCModule_DeleteComponent(
        ctypes.c_int32(窗口序号),
        auto_encode(组件名),
        ctypes.c_bool(是否主线程)
    )
    return ret

# INT64 __stdcall HCModule_CALL(int winIndex, char* componentName, char* functionName, INT64 rcx, INT64 rdx, INT64 r8, INT64 r9, INT64 l5, INT64 l6, BOOL mainThread);
def HD插件_CALL(窗口序号: int, 组件名: str, 函数名: str, rcx: int = 0, rdx: int = 0, r8: int = 0, r9: int = 0, l5: int = 0, l6: int = 0, 是否主线程: bool = False) -> int:
    """
    调用自定义组件接口
    
    Args:
        窗口序号: 窗口序号
        组件名: 组件文件名（不含.dll）
        函数名: 目标函数名称
        rcx: CALL参数1
        rdx: CALL参数2
        r8: CALL参数3
        r9: CALL参数4
        l5: CALL参数5
        l6: CALL参数6
        是否主线程: 需挂接主线程
    
    Returns:
        int: 返回值代码（查看HD返回值表）
    """
    hd = Config.get_hd()
    
    HCModule_CALL = hd.HCModule_CALL
    HCModule_CALL.restype = ctypes.c_int64
    HCModule_CALL.argtypes = [ctypes.c_int32, ctypes.c_char_p, ctypes.c_char_p, ctypes.c_int64, ctypes.c_int64, ctypes.c_int64, ctypes.c_int64, ctypes.c_int64, ctypes.c_int64, ctypes.c_bool]
    
    ret = HCModule_CALL(
        ctypes.c_int32(窗口序号),
        auto_encode(组件名),
        auto_encode(函数名),
        ctypes.c_int64(rcx),
        ctypes.c_int64(rdx),
        ctypes.c_int64(r8),
        ctypes.c_int64(r9),
        ctypes.c_int64(l5),
        ctypes.c_int64(l6),
        ctypes.c_bool(是否主线程)
    )
    return ret

# INT64 __stdcall HCModule_CALLEx(int winIndex, char* componentName, char* functionName, INT64 rcx, INT64 rdx, INT64 r8, INT64 r9, INT64 l5, INT64 l6, char* buffer, int bufferSize, BOOL mainThread);
def HD插件_CALLEx(窗口序号: int, 组件名: str, 函数名: str, rcx: int = 0, rdx: int = 0, r8: int = 0, r9: int = 0, l5: int = 0, l6: int = 0, 缓冲区数据: bytes = None, 缓冲区大小: int = 0, 是否主线程: bool = False) -> int:
    """
    调用自定义组件接口（扩展版本）
    
    Args:
        窗口序号: 窗口序号
        组件名: 组件文件名（不含.dll）
        函数名: 目标函数名称
        rcx: CALL参数1
        rdx: CALL参数2
        r8: CALL参数3
        r9: CALL参数4
        l5: CALL参数5
        l6: CALL参数6
        缓冲区数据: 二进制缓冲区数据 (bytes) - 字节数组，如：b'\x01\x02\x03' 或 bytes([1, 2, 3])
        缓冲区大小: 缓冲区大小（最大支持1024*100字节）
        是否主线程: 需挂接主线程
    
    Returns:
        int: 返回值代码（查看HD返回值表）
    """
    hd = Config.get_hd()
    
    HCModule_CALLEx = hd.HCModule_CALLEx
    HCModule_CALLEx.restype = ctypes.c_int64
    HCModule_CALLEx.argtypes = [ctypes.c_int32, ctypes.c_char_p, ctypes.c_char_p, ctypes.c_int64, ctypes.c_int64, ctypes.c_int64, ctypes.c_int64, ctypes.c_int64, ctypes.c_int64, ctypes.c_char_p, ctypes.c_int32, ctypes.c_bool]
    
    # 处理缓冲区数据
    if 缓冲区数据 is not None:
        buffer_ptr = ctypes.c_char_p(缓冲区数据)
    else:
        buffer_ptr = None
    
    ret = HCModule_CALLEx(
        ctypes.c_int32(窗口序号),
        auto_encode(组件名),
        auto_encode(函数名),
        ctypes.c_int64(rcx),
        ctypes.c_int64(rdx),
        ctypes.c_int64(r8),
        ctypes.c_int64(r9),
        ctypes.c_int64(l5),
        ctypes.c_int64(l6),
        buffer_ptr,
        ctypes.c_int32(缓冲区大小),
        ctypes.c_bool(是否主线程)
    )
    return ret





from .config import Config, ctypes
from .config import auto_encode

# INT64 __stdcall HCN_NormalInstallPlugX86(int pid);
def HD注入_普通安装插件X86(进程PID: int) -> int:
    """
    HD普通安装插件(X86),不需要安装驱动,这个不是无痕无模块注入,只支持32位的
    :param 进程PID: 进程PID
    :return: 返回值代码 (查看HD返回值表)
    """
    hd = Config.get_hd()

    HCN_NormalInstallPlugX86 = hd.HCN_NormalInstallPlugX86
    HCN_NormalInstallPlugX86.restype = ctypes.c_int64
    HCN_NormalInstallPlugX86.argtypes = [ctypes.c_int32]

    ret = HCN_NormalInstallPlugX86(ctypes.c_int32(进程PID))

    return ret


# INT64 __stdcall HCN_NormalInstallPlugX86Ex(INT64 topHwnd);
def HD注入_普通安装插件X86Ex(窗口句柄: int) -> int:
    """
    HD普通安装插件(扩展版本X86),不需要安装驱动,这个不是无痕无模块注入,只支持32位的
    :param 窗口句柄: 窗口句柄
    :return: 返回值代码 (查看HD返回值表)
    """
    hd = Config.get_hd()

    HCN_NormalInstallPlugX86Ex = hd.HCN_NormalInstallPlugX86Ex
    HCN_NormalInstallPlugX86Ex.restype = ctypes.c_int64
    HCN_NormalInstallPlugX86Ex.argtypes = [ctypes.c_int64]

    ret = HCN_NormalInstallPlugX86Ex(ctypes.c_int64(窗口句柄))

    return ret


# INT64 __stdcall HCN_NormalInstallPlugX64(int pid);
def HD注入_普通安装插件X64(进程PID: int) -> int:
    """
    HD普通安装插件(X64),不需要安装驱动,这个不是无痕无模块注入,只支持64位的
    :param 进程PID: 进程PID
    :return: 返回值代码 (查看HD返回值表)
    """
    hd = Config.get_hd()

    HCN_NormalInstallPlugX64 = hd.HCN_NormalInstallPlugX64
    HCN_NormalInstallPlugX64.restype = ctypes.c_int64
    HCN_NormalInstallPlugX64.argtypes = [ctypes.c_int32]

    ret = HCN_NormalInstallPlugX64(ctypes.c_int32(进程PID))

    return ret


# INT64 __stdcall HCN_NormalInstallPlugX64Ex(INT64 topHwnd);
def HD注入_普通安装插件X64Ex(窗口句柄: int) -> int:
    """
    HD普通安装插件(扩展版本X64),不需要安装驱动,这个不是无痕无模块注入,只支持64位的
    :param 窗口句柄: 窗口句柄
    :return: 返回值代码 (查看HD返回值表)
    """
    hd = Config.get_hd()

    HCN_NormalInstallPlugX64Ex = hd.HCN_NormalInstallPlugX64Ex
    HCN_NormalInstallPlugX64Ex.restype = ctypes.c_int64
    HCN_NormalInstallPlugX64Ex.argtypes = [ctypes.c_int64]

    ret = HCN_NormalInstallPlugX64Ex(ctypes.c_int64(窗口句柄))

    return ret


# INT64 __stdcall HCHD_NormalInstallPlugX86X64(int pid, int dllBits, BOOL bWait);
def HD注入_驱动安装插件(进程PID: int, DLL位数: int, 是否等待: bool = True) -> int:
    """
    把插件安装到指定进程中,不是无痕无模块注入(方式1)
    :param 进程PID: 进程PID
    :param DLL位数: DLL位数
    :param 是否等待: 是否等待 (已废弃无效) (默认True)
    :return: 返回值代码 (查看HD驱动返回值表)
    """
    hd = Config.get_hd()

    HCHD_NormalInstallPlugX86X64 = hd.HCHD_NormalInstallPlugX86X64
    HCHD_NormalInstallPlugX86X64.restype = ctypes.c_int64
    HCHD_NormalInstallPlugX86X64.argtypes = [ctypes.c_int32, ctypes.c_int32, ctypes.c_bool]

    ret = HCHD_NormalInstallPlugX86X64(
        ctypes.c_int32(进程PID),
        ctypes.c_int32(DLL位数),
        ctypes.c_bool(是否等待)
    )

    return ret


# INT64 __stdcall HCHD_NormalInjectX86X64ByFile(int pid, char *DLL绝对路径A, BOOL bWait);
def HD注入_驱动注入DLL(进程PID: int, DLL绝对路径: str, 是否等待: bool = True) -> int:
    """
    把DLL注入到指定进程中,不是无痕无模块注入(方式1)
    :param 进程PID: 进程PID
    :param DLL绝对路径: DLL全路径
    :param 是否等待: 是否等待 (已废弃无效) (默认True)
    :return: 返回值代码 (查看HD驱动返回值表)
    """
    hd = Config.get_hd()

    HCHD_NormalInjectX86X64ByFile = hd.HCHD_NormalInjectX86X64ByFile
    HCHD_NormalInjectX86X64ByFile.restype = ctypes.c_int64
    HCHD_NormalInjectX86X64ByFile.argtypes = [ctypes.c_int32, ctypes.c_char_p, ctypes.c_bool]

    # 使用auto_encode自动转换编码
    dll_path_bytes = auto_encode(DLL绝对路径)

    ret = HCHD_NormalInjectX86X64ByFile(
        ctypes.c_int32(进程PID),
        dll_path_bytes,
        ctypes.c_bool(是否等待)
    )

    return ret


# INT64 __stdcall HCHD_NormalInstallPlugX86X64Ex(int pid, int dllBits, BOOL bWait);
def HD注入_驱动安装插件Ex(进程PID: int, DLL位数: int, 是否等待: bool = True) -> int:
    """
    把插件安装到指定进程中,不是无痕无模块注入(方式2,方式1的加强版本)
    :param 进程PID: 进程PID
    :param DLL位数: DLL位数
    :param 是否等待: 是否等待 (已废弃无效) (默认True)
    :return: 返回值代码 (查看HD驱动返回值表)
    """
    hd = Config.get_hd()

    HCHD_NormalInstallPlugX86X64Ex = hd.HCHD_NormalInstallPlugX86X64Ex
    HCHD_NormalInstallPlugX86X64Ex.restype = ctypes.c_int64
    HCHD_NormalInstallPlugX86X64Ex.argtypes = [ctypes.c_int32, ctypes.c_int32, ctypes.c_bool]

    ret = HCHD_NormalInstallPlugX86X64Ex(
        ctypes.c_int32(进程PID),
        ctypes.c_int32(DLL位数),
        ctypes.c_bool(是否等待)
    )

    return ret


# INT64 __stdcall HCHD_NormalInjectX86X64ByFileEx(int pid, char *DLL绝对路径A, BOOL bWait);
def HD注入_驱动注入DLLEx(进程PID: int, DLL绝对路径: str, 是否等待: bool = True) -> int:
    """
    把DLL注入到指定进程中,不是无痕无模块注入(方式2,方式1的加强版本)
    :param 进程PID: 进程PID
    :param DLL绝对路径: DLL全路径
    :param 是否等待: 是否等待 (已废弃无效) (默认True)
    :return: 返回值代码 (查看HD驱动返回值表)
    """
    hd = Config.get_hd()

    HCHD_NormalInjectX86X64ByFileEx = hd.HCHD_NormalInjectX86X64ByFileEx
    HCHD_NormalInjectX86X64ByFileEx.restype = ctypes.c_int64
    HCHD_NormalInjectX86X64ByFileEx.argtypes = [ctypes.c_int32, ctypes.c_char_p, ctypes.c_bool]

    # 使用auto_encode自动转换编码
    dll_path_bytes = auto_encode(DLL绝对路径)

    ret = HCHD_NormalInjectX86X64ByFileEx(
        ctypes.c_int32(进程PID),
        dll_path_bytes,
        ctypes.c_bool(是否等待)
    )

    return ret


# INT64 __stdcall HCInject_SetPlugin(char* 发布版本DLL名, char* 调试版本DLL名);
def HD注入_设置插件信息(发布版本DLL名: str = None, 调试版本DLL名: str = None) -> int:
    """
    设置插件信息
    :param 发布版本DLL名: 发布版本DLL名 (为空则根据不同版本内置了DLL名字) (默认None)
    :param 调试版本DLL名: 调试版本DLL名 (为空则根据不同版本内置了DLL名字) (默认None)
    :return: 返回值代码 (查看HD驱动返回值表)
    """
    hd = Config.get_hd()

    HCInject_SetPlugin = hd.HCInject_SetPlugin
    HCInject_SetPlugin.restype = ctypes.c_int64
    HCInject_SetPlugin.argtypes = [ctypes.c_char_p, ctypes.c_char_p]

    # 使用auto_encode自动转换编码（如果为None则传递NULL）
    release_dll_bytes = auto_encode(发布版本DLL名) if 发布版本DLL名 else None
    debug_dll_bytes = auto_encode(调试版本DLL名) if 调试版本DLL名 else None

    ret = HCInject_SetPlugin(release_dll_bytes, debug_dll_bytes)

    return ret


import ctypes
from enum import Enum

class HD配置(Enum):
    HD缓冲区大小 = 1024 * 200
    HD多开数量 = 62

class Config:
    _hd = None

    @staticmethod
    def load_dll(dll_path):
        try:
            Config._hd = ctypes.windll.LoadLibrary(dll_path)
        except Exception as e:
            print(f"加载DLL失败: {e}")

    @staticmethod
    def get_hd():
        return Config._hd


# ============================================自动转码
def auto_encode(text: str) -> bytes:
    """
    自动编码函数，根据文本内容选择合适的编码方式
    Args:
        text: 要编码的字符串
    Returns:
        bytes: 编码后的字节数组
    """
    if not isinstance(text, str):
        raise TypeError(f"Expected str, got {type(text)}")
    
    try:
        # 检查是否包含中文字符
        if any('\u4e00' <= ch <= '\u9fff' for ch in text):
            return text.encode('gbk')
        else:
            return text.encode('utf-8')
    except UnicodeEncodeError:
        # 如果GBK编码失败，尝试UTF-8
        try:
            return text.encode('utf-8')
        except UnicodeEncodeError:
            # 如果UTF-8也失败，使用错误替换策略
            return text.encode('utf-8', errors='replace')


from .config import Config, ctypes
from .config import auto_encode

def HDVM_运行(
    windowsIndex: int,
    vmPath: str,
    vmxSysPath: str,
    bGui: bool = False,
    lparam: str = None,
    vmType: int = 0,
    type_: int = 0
) -> int:
    """
    接口说明:
        运行虚拟机(管理员运行)

    函数原型：
        __int64  __stdcall  HCVM_Run(__int32 windowsIndex, char* vmPath, char* vmxSysPath, BOOL bGui = FALSE, char* lparam = NULL, long vmType = 0, long type = 0);

    参数说明:
        windowsIndex: 窗口序号 表示只是打开虚拟机 注意:大于0表示重置对应窗口序号下的DMA环境
        vmPath: VM安装路径 如:"D:\vm16\"
        vmxSysPath: 虚拟机vmx路径 如:"D:/vmwin10/Windows10x64.vmx"
        bGui: 是否界面GUI显示启动虚拟机
        lparam: 额外命令参数
        vmType: 0 VMware Workstation -T ws(默认) 1 VMware Player -T player
        type_: 默认0 保留

    返回值:
        int: 0 1（查看HD返回值表）

    备注:
        指令:
        D:\vmwin10>D:\vm16\vmrun -T ws start "D:/vmwin10/Windows10x64.vmx" gui lparam
        D:\vmwin10>D:\vm16\vmrun -T ws start "D:/vmwin10/Windows10x64.vmx" nogui lparam
        C++案例:
        auto ret = HCVM_Run(0, "D:\\vm16\\", "D:\\vmwin10\\Windows 10 x64.vmx", TRUE, 0, 0, 0);
    """
    hd = Config.get_hd()
    HCVM_Run = hd.HCVM_Run
    HCVM_Run.restype = ctypes.c_int64
    HCVM_Run.argtypes = [ctypes.c_int32, ctypes.c_char_p, ctypes.c_char_p, ctypes.c_bool, ctypes.c_char_p, ctypes.c_long, ctypes.c_long]
    vmPath_bytes = auto_encode(vmPath)
    vmxSysPath_bytes = auto_encode(vmxSysPath)
    lparam_bytes = auto_encode(lparam) if lparam else None
    ret = HCVM_Run(
        ctypes.c_int32(windowsIndex),
        vmPath_bytes,
        vmxSysPath_bytes,
        ctypes.c_bool(bGui),
        lparam_bytes,
        ctypes.c_long(vmType),
        ctypes.c_long(type_)
    )
    return ret

def HDVM_重启(
    windowsIndex: int,
    vmPath: str,
    vmxSysPath: str,
    bForceRoot: bool = True,
    bGui: bool = False,
    lparam: str = None,
    vmType: int = 0,
    type_: int = 0
) -> int:
    """
    接口说明:
        重启运行虚拟机(管理员运行)

    函数原型：
        __int64  __stdcall   HCVM_Rerun(__int32 windowsIndex, char* vmPath, char* vmxSysPath, BOOL bForceRoot = TRUE, BOOL bGui = FALSE, char* lparam = NULL, long vmType = 0, long type = 0);

    参数说明:
        windowsIndex: 窗口序号
        vmPath: VM安装路径
        vmxSysPath: 虚拟机vmx路径
        bForceRoot: 是否强制重启（类似断电）反之表示正常重启（需 VMware Tools 支持）
        bGui: 是否界面GUI显示启动虚拟机
        lparam: 额外命令参数
        vmType: 0 VMware Workstation -T ws(默认) 1 VMware Player -T player
        type_: 默认0 保留

    返回值:
        int: 0 1（查看HD返回值表）

    备注:
        指令:
        D:\vmwin10>D:\vm16\vmrun -T ws restart "D:/vmwin10/Windows10x64.vmx" gui lparam
        D:\vmwin10>D:\vm16\vmrun -T ws restart "D:/vmwin10/Windows10x64.vmx" nogui lparam
        C++案例:
        auto ret = HCVM_Rerun(0, "D:\\vm16\\", "D:\\vmwin10\\Windows 10 x64.vmx", m_强制关闭CheckBox.GetCheck(), TRUE, 0, 0, 0);
    """
    hd = Config.get_hd()
    HCVM_Rerun = hd.HCVM_Rerun
    HCVM_Rerun.restype = ctypes.c_int64
    HCVM_Rerun.argtypes = [ctypes.c_int32, ctypes.c_char_p, ctypes.c_char_p, ctypes.c_bool, ctypes.c_bool, ctypes.c_char_p, ctypes.c_long, ctypes.c_long]
    vmPath_bytes = auto_encode(vmPath)
    vmxSysPath_bytes = auto_encode(vmxSysPath)
    lparam_bytes = auto_encode(lparam) if lparam else None
    ret = HCVM_Rerun(
        ctypes.c_int32(windowsIndex),
        vmPath_bytes,
        vmxSysPath_bytes,
        ctypes.c_bool(bForceRoot),
        ctypes.c_bool(bGui),
        lparam_bytes,
        ctypes.c_long(vmType),
        ctypes.c_long(type_)
    )
    return ret

def HDVM_关闭(
    windowsIndex: int,
    vmPath: str,
    vmxSysPath: str,
    bForceRoot: bool = True,
    vmType: int = 0,
    type_: int = 0
) -> int:
    """
    接口说明:
        关闭运行虚拟机(管理员运行)

    函数原型：
        __int64  __stdcall   HCVM_Close(__int32 windowsIndex, char* vmPath, char* vmxSysPath, BOOL bForceRoot = TRUE, long vmType = 0, long type = 0);

    参数说明:
        windowsIndex: 窗口序号
        vmPath: VM安装路径
        vmxSysPath: 虚拟机vmx路径
        bForceRoot: 是否强制重启（类似断电）反之表示正常重启（需 VMware Tools 支持）
        vmType: 0 VMware Workstation -T ws(默认) 1 VMware Player -T player
        type_: 默认0 保留

    返回值:
        int: 0 1（查看HD返回值表）

    备注:
        指令:
        D:\vmwin10>D:\vm16\vmrun -T ws stop "D:/vmwin10/Windows10x64.vmx"
        D:\vmwin10>D:\vm16\vmrun -T ws stop "D:/vmwin10/Windows10x64.vmx"
        C++案例:
        auto ret = HCVM_Close(0, "D:\\vm16\\", "D:\\vmwin10\\Windows 10 x64.vmx", m_强制关闭CheckBox.GetCheck(), 0, 0);
    """
    hd = Config.get_hd()
    HCVM_Close = hd.HCVM_Close
    HCVM_Close.restype = ctypes.c_int64
    HCVM_Close.argtypes = [ctypes.c_int32, ctypes.c_char_p, ctypes.c_char_p, ctypes.c_bool, ctypes.c_long, ctypes.c_long]
    vmPath_bytes = auto_encode(vmPath)
    vmxSysPath_bytes = auto_encode(vmxSysPath)
    ret = HCVM_Close(
        ctypes.c_int32(windowsIndex),
        vmPath_bytes,
        vmxSysPath_bytes,
        ctypes.c_bool(bForceRoot),
        ctypes.c_long(vmType),
        ctypes.c_long(type_)
    )
    return ret

def HDVM_遍历(
    vmPath: str
) -> int:
    """
    接口说明:
        获取当前正在运行的虚拟机路径 和 总数(管理员运行)

    函数原型：
        __int64  __stdcall   HCVM_List(char* vmPath);

    参数说明:
        vmPath: VM安装路径 如:"D:\vm16\"

    返回值:
        int: 数量
        返回的json: "|"隔开 如:"D:/vmwin10/Windows10x64_1.vmx|D:/vmwin10/Windows10x64_2.vmx|D:/vmwin10/Windows10x64_3.vmx"

    备注:
        无
        C++案例:
        auto ret = HCVM_List("D:\\vm16\\");
    """
    hd = Config.get_hd()
    HCVM_List = hd.HCVM_List
    HCVM_List.restype = ctypes.c_int64
    HCVM_List.argtypes = [ctypes.c_char_p]
    vmPath_bytes = auto_encode(vmPath)
    ret = HCVM_List(vmPath_bytes)
    return ret

def HDVM_是否开启(
    vmPath: str,
    vmxSysPath: str
) -> int:
    """
    接口说明:
        指定虚拟机是否已经开启(管理员运行)

    函数原型：
        __int64  __stdcall   HCVM_IsStart(char* vmPath, char* vmxSysPath);

    参数说明:
        vmPath: VM安装路径 如:"D:\vm16\"
        vmxSysPath: 虚拟机vmx路径 如:"D:/vmwin10/Windows10x64_1.vmx"

    返回值:
        int: 0 1（查看HD返回值表）

    备注:
        无
        C++案例:
        auto ret = HCVM_List("D:\\vm16\\","D:/vmwin10/Windows10x64_1.vmx");
    """
    hd = Config.get_hd()
    HCVM_IsStart = hd.HCVM_IsStart
    HCVM_IsStart.restype = ctypes.c_int64
    HCVM_IsStart.argtypes = [ctypes.c_char_p, ctypes.c_char_p]
    vmPath_bytes = auto_encode(vmPath)
    vmxSysPath_bytes = auto_encode(vmxSysPath)
    ret = HCVM_IsStart(vmPath_bytes, vmxSysPath_bytes)
    return ret


from .config import Config, ctypes
from .config import auto_encode

# __int64  __stdcall HCPOCR_AddModel (char* det_infer, char* cls_infer, char* rec_infer, char* keys,char* parameterjson,char* password = NULL);
def HDPOCR_添加模型(det_infer: str,cls_infer: str,rec_infer: str,keys: str,parameterjson: str,password: str) -> int:
    """
    添加onnx字库模型并开启OCR服务 (组件7)
    多次调用会自动关闭之前的服务然后重启

    Args:
        det_infer:训练模型onnx 如:ch_PP-OCRv5_mobile_det.onnx
        cls_infer:校验模型onnx 如:ch_PP-OCRv5_rec_mobile_infer.onnx
        rec_infer:方向模型onnx 如:ch_ppocr_mobile_v2.0_cls_infer.onnx 一般不指定默认使用官方默认的
        keys:字典字库文件txt 如:ppocrv5_dict.txt 一般官方有字集文件 如果没有就自己写一个 一行一个字
        parameterjson:参数json格式字符串
        password:模型加解密密码 调试版本不能使用加载模型
    Returns:
        int: 返回值代码（查看HD返回值表）

    Note:
    需要调用HCHD_LoadDrv2 传递参数7来安装HPOCR组件模块
    json配置参数:"{ \"cpu_mem\":0,\"cpu_threads\":2,\"use_gpu\":false,\"gpu_id\":-1,\"gpu_mem\":1024,\"padding\":50,\"maxSideLen\":1024,\"boxScoreThresh\":0.5,\"boxThresh\":0.3,\"unClipRatio\":1.6,\"doAngle\":true,\"mostAngle\":true,\"visualize\":false,\"enable_log\":false,\"isOutputConsole\":true}";
    """
    hd = Config.get_hd()

    HCPOCR_AddModel = hd.HCPOCR_AddModel
    HCPOCR_AddModel.restype = ctypes.c_int64
    HCPOCR_AddModel.argtypes = [
        ctypes.c_char_p,
        ctypes.c_char_p,
        ctypes.c_char_p,
        ctypes.c_char_p,
        ctypes.c_char_p,
        ctypes.c_char_p
    ]

    ret = HCPOCR_AddModel (auto_encode(det_infer),auto_encode(cls_infer),auto_encode(rec_infer),auto_encode(keys),  auto_encode(parameterjson),auto_encode(password))
    return ret


# __int64  __stdcall HCPOCR_Identify(__int32 windIndex, int x = -1, int y = -1, int w = -1, int h = -1, float conf = 0.7f, int fType  = 0, BOOL retText = TRUE, BOOL bDebug = FALSE);
def HDPOCR_识别(windIndex: int,x: int,y: int,w: int,h: int,conf: float,fType: int,retText: bool,bDebug: bool) -> int:
    """
    基于截图缓存识别 (组件7)

    Args:
        windIndex:窗口序号
        x,y,w,h:左上角+宽度+高度 全为-1表示全图 内部自动修正
        conf:每个字或字符的相似度 当retText为真同时大于0 表示对每个字符置信度进程过滤(返回匹配的字符数量) 当retText为真同时conf小于等于0表示直接返回字符串(不过滤)(有字符串返回1空字符串返回0)
        fType:过滤类型 0 默认表示字符串每个字符的相似度的总和然后求平均值,最后conf和这个平均值比较(返回值表示匹配的字符串数量) 1 表示每个字符单独的相似度比较(返回值表示匹配的字符数量)
        retText:是否仅返回文本信息 设置为真表示需要对文本进程处理 具体如何处理看conf置信度的值大小 反之设置为假包含各种坐标属性json信息(始终返回1 需要自行解析json)
        bDebug:是否调试查看识别图片

    Returns:
        int: 返回值代码（查看HD返回值表）

    Note:
    需要调用HCHD_LoadDrv2 传递参数7来安装HPOCR组件模块
    json配置参数:"{ \"cpu_mem\":0,\"cpu_threads\":2,\"use_gpu\":false,\"gpu_id\":-1,\"gpu_mem\":1024,\"padding\":50,\"maxSideLen\":1024,\"boxScoreThresh\":0.5,\"boxThresh\":0.3,\"unClipRatio\":1.6,\"doAngle\":true,\"mostAngle\":true,\"visualize\":false,\"enable_log\":false,\"isOutputConsole\":true}";
    """
    hd = Config.get_hd()

    HCPOCR_Identify = hd.HCPOCR_Identify
    HCPOCR_Identify.restype = ctypes.c_int64
    HCPOCR_Identify.argtypes = [
        ctypes.c_int32,
        ctypes.c_int32,
        ctypes.c_int32,
        ctypes.c_int32,
        ctypes.c_int32,
        ctypes.c_float,
        ctypes.c_int32,
        ctypes.c_bool,
        ctypes.c_bool
    ]

    ret = HCPOCR_Identify (ctypes.c_int32(windIndex),ctypes.c_int32(x),ctypes.c_int32(y),ctypes.c_int32(w),ctypes.c_int32(h),ctypes.c_float(conf),ctypes.c_int32(fType),ctypes.c_bool(retText),ctypes.c_bool(bDebug))
    return ret


# __int64  __stdcall HCPOCR_IdentifyByFile(__int32 windIndex, char* imageFile, float conf = 0.7f, int fType = 0, BOOL retText = TRUE, BOOL bDebug = FALSE);
def HDPOCR_识别图片(windIndex: int,imageFile:str,conf: float,fType: int,retText: bool,bDebug: bool) -> int:
    """
    基于截图缓存识别 (组件7)

    Args:
        windIndex:窗口序号
        imageFile:图片路径(绝对路径或者相对路径)
        conf:每个字或字符的相似度 当retText为真同时大于0 表示对每个字符置信度进程过滤(返回匹配的字符数量) 当retText为真同时conf小于等于0表示直接返回字符串(不过滤)(有字符串返回1空字符串返回0)
        fType:过滤类型 0 默认表示字符串每个字符的相似度的总和然后求平均值,最后conf和这个平均值比较(返回值表示匹配的字符串数量) 1 表示每个字符单独的相似度比较(返回值表示匹配的字符数量)
        retText:是否仅返回文本信息 设置为真表示需要对文本进程处理 具体如何处理看conf置信度的值大小 反之设置为假包含各种坐标属性json信息(始终返回1 需要自行解析json)
        bDebug:是否调试查看识别图片

    Returns:
        int: 返回值代码（查看HD返回值表）

    Note:
    需要调用HCHD_LoadDrv2 传递参数7来安装HPOCR组件模块
    json配置参数:"{ \"cpu_mem\":0,\"cpu_threads\":2,\"use_gpu\":false,\"gpu_id\":-1,\"gpu_mem\":1024,\"padding\":50,\"maxSideLen\":1024,\"boxScoreThresh\":0.5,\"boxThresh\":0.3,\"unClipRatio\":1.6,\"doAngle\":true,\"mostAngle\":true,\"visualize\":false,\"enable_log\":false,\"isOutputConsole\":true}";
    """
    hd = Config.get_hd()

    HCPOCR_Identify = hd.HCPOCR_Identify
    HCPOCR_Identify.restype = ctypes.c_int64
    HCPOCR_Identify.argtypes = [
        ctypes.c_int32,
        ctypes.c_char_p,
        ctypes.c_float,
        ctypes.c_int32,
        ctypes.c_bool,
        ctypes.c_bool
    ]

    ret = HCPOCR_Identify (ctypes.c_int32(windIndex),auto_encode(imageFile),ctypes.c_float(conf),ctypes.c_int32(fType),ctypes.c_bool(retText),ctypes.c_bool(bDebug))
    return ret


# __int64  __stdcall HCPOCR_IdentifyByMem(__int32 windIndex, void* imagebytedata, int size, float conf = 0.7f, int fType = 0, BOOL retText = TRUE, BOOL bDebug = FALSE);
def HDPOCR_识别图片数据(windIndex: int,imagebytedata:bytes,size:int,conf: float,fType: int,retText: bool,bDebug: bool) -> int:
    """
    基于指定图片内存识别 (组件7)

    Args:
        windIndex:窗口序号
        imagebytedata:一般是BMP图片数据 包含头+数据
        size:图片数据大小
        conf:每个字或字符的相似度 当retText为真同时大于0 表示对每个字符置信度进程过滤(返回匹配的字符数量) 当retText为真同时conf小于等于0表示直接返回字符串(不过滤)(有字符串返回1空字符串返回0)
        fType:过滤类型 0 默认表示字符串每个字符的相似度的总和然后求平均值,最后conf和这个平均值比较(返回值表示匹配的字符串数量) 1 表示每个字符单独的相似度比较(返回值表示匹配的字符数量)
        retText:是否仅返回文本信息 设置为真表示需要对文本进程处理 具体如何处理看conf置信度的值大小 反之设置为假包含各种坐标属性json信息(始终返回1 需要自行解析json)
        bDebug:是否调试查看识别图片

    Returns:
        int: 返回值代码（查看HD返回值表）

    Note:
    需要调用HCHD_LoadDrv2 传递参数7来安装HPOCR组件模块
    json配置参数:"{ \"cpu_mem\":0,\"cpu_threads\":2,\"use_gpu\":false,\"gpu_id\":-1,\"gpu_mem\":1024,\"padding\":50,\"maxSideLen\":1024,\"boxScoreThresh\":0.5,\"boxThresh\":0.3,\"unClipRatio\":1.6,\"doAngle\":true,\"mostAngle\":true,\"visualize\":false,\"enable_log\":false,\"isOutputConsole\":true}";
    """
    hd = Config.get_hd()

    HCPOCR_IdentifyByMem = hd.HCPOCR_IdentifyByMem
    HCPOCR_IdentifyByMem.restype = ctypes.c_int64
    HCPOCR_IdentifyByMem.argtypes = [
        ctypes.c_int32,
        ctypes.POINTER(ctypes.c_ubyte),
        ctypes.c_int32,
        ctypes.c_float,
        ctypes.c_int32,
        ctypes.c_bool,
        ctypes.c_bool
    ]

    # 创建字节数组
    buffer = (ctypes.c_ubyte * len(imagebytedata))(*imagebytedata)

    ret = HCPOCR_IdentifyByMem (ctypes.c_int32(windIndex),buffer,ctypes.c_int32(size),ctypes.c_float(conf),ctypes.c_int32(fType),ctypes.c_bool(retText),ctypes.c_bool(bDebug))
    return ret